# Generated by Django 3.0.2 on 2020-01-29 10:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hazard_feed', '0003_weatherrecipients'),
    ]

    operations = [
        migrations.AddField(
            model_name='hazardfeeds',
            name='is_sent',
            field=models.BooleanField(default=False),
        ),
    ]
