# Generated by Django 3.0.2 on 2020-10-26 19:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hazard_feed', '0016_auto_20201001_2227'),
    ]

    operations = [
        migrations.AddField(
            model_name='weatherrecipients',
            name='hazard_levels',
            field=models.ManyToManyField(blank=True, to='hazard_feed.HazardLevels'),
        ),
    ]
