# Generated by Django 3.0.2 on 2020-09-29 15:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hazard_feed', '0014_remove_emailactivationcode_session'),
    ]

    operations = [
        migrations.AddField(
            model_name='hazardfeeds',
            name='date_end',
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name='hazardfeeds',
            name='date_start',
            field=models.DateField(null=True),
        ),
    ]
