# Generated by Django 3.0.2 on 2020-07-31 14:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('hazard_feed', '0013_emailactivationcode_is_activate'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='emailactivationcode',
            name='session',
        ),
    ]
