# Generated by Django 3.0.2 on 2020-03-22 15:20

from django.db import migrations, models
import django.db.models.deletion
import hazard_feed.models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('sessions', '0001_initial'),
        ('hazard_feed', '0011_rss_feed_url_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='weatherrecipients',
            name='email',
            field=models.EmailField(max_length=254, unique=True),
        ),
        migrations.CreateModel(
            name='EmailActivationCode',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ('code', models.CharField(default=hazard_feed.models.gen_act_code, editable=False, max_length=256)),
                ('date_created', models.DateTimeField(auto_now_add=True, null=True)),
                ('session', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='sessions.Session')),
                ('target', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='hazard_feed.WeatherRecipients')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
