# Generated by Django 3.0.2 on 2020-11-04 05:06

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('hazard_feed', '0017_weatherrecipients_hazard_levels'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='emailactivationcode',
            name='is_activate',
        ),
        migrations.RemoveField(
            model_name='emailactivationcode',
            name='target',
        ),
        migrations.AddField(
            model_name='weatherrecipients',
            name='code',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='hazard_feed.EmailActivationCode'),
        ),
    ]
