# Generated by Django 3.0.2 on 2020-02-04 20:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hazard_feed', '0004_hazardfeeds_is_sent'),
    ]

    operations = [
        migrations.AddField(
            model_name='hazardfeeds',
            name='date_created',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='hazardfeeds',
            name='date_send',
            field=models.DateTimeField(null=True),
        ),
        migrations.AlterField(
            model_name='hazardfeeds',
            name='date_modified',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
    ]
