# Generated by Django 3.0.2 on 2020-11-04 09:40

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('hazard_feed', '0018_auto_20201104_0806'),
    ]

    operations = [
        migrations.CreateModel(
            name='WeatherRecipientsEditCandidate',
            fields=[
                ('title', models.CharField(max_length=64, null=True)),
                ('valid', models.BooleanField(default=False)),
                ('target', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, primary_key=True, serialize=False, to='hazard_feed.WeatherRecipients')),
                ('hazard_levels', models.ManyToManyField(blank=True, to='hazard_feed.HazardLevels')),
            ],
        ),
    ]
