# Generated by Django 3.0.2 on 2020-02-19 14:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hazard_feed', '0009_initial_email_templates_import'),
    ]

    operations = [
        migrations.CreateModel(
            name='RSSFeedUrl',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date_created', models.DateTimeField(auto_now_add=True, null=True)),
                ('date_modified', models.DateTimeField(auto_now=True, null=True)),
                ('title', models.CharField(max_length=32)),
                ('url', models.URLField()),
                ('is_active', models.BooleanField(default=False)),
            ],
            options={
                'verbose_name': 'RSS feed URL',
                'verbose_name_plural': 'RSS feed URLs ',
            },
        ),
    ]
