<p>Здравствуйте</p>
<span> </span>
<span> </span>
<p>Для потверждения подписки на оповещения о неблагоприятных погодных явления вам был отправлен код активации</p>
<span></span>
<span></span>
<p>Код активации: <b><strong>{{ code }}</strong></b></p>